@@ -20,6 +20,9 @@ TRACKING_ITEM_CHOICES = (
 class TrackingItem(TranslatableModel):
     translations = TranslatedFields(
         name=models.CharField(_('Name'), max_length=1024),
+        description=models.TextField(_('Description'), blank=True, null=True, help_text=_('What\'s the cookie\'s purpose?')),
+        lifetime=models.CharField(_('Lifetime'), max_length=255, blank=True, null=True, help_text=_('The cookie\'s liftime (e.g. 1 Year)')),
+        domain=models.CharField(_('Domain'), max_length=1024, blank=True, null=True, help_text=_('Domain of the cookie (e.g. .domain.com)')),
     )
 
     category = models.CharField(
@@ -35,7 +38,6 @@ class TrackingItem(TranslatableModel):
     site = models.ManyToManyField(
         Site,
         blank=True,
-        null=True
     )
 
     def __unicode__(self):
